mmoll_mgdl = 18.018
mgdl_mmoll = 1/mmoll_mgdl

glucose_levels = {'hypo'    : (0,70-1e-8),
                  'hypo L2' : (0,54-1e-8),
                  'hypo L1' : (54,70-1e-8),
                  'target'  : (70,180),
                  'hyper'   : (180+1e-8,1e4),
                  'hyper L1': (180+1e-8,250),
                  'hyper L2': (250+1e-8,1e4)}